"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; } function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } } function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }
var _ethers = require('ethers');

var _THORCHAIN_SWAP_ABI = require('./abi/THORCHAIN_SWAP_ABI'); var _THORCHAIN_SWAP_ABI2 = _interopRequireDefault(_THORCHAIN_SWAP_ABI);
var _UNISWAP_V2_ERC20_ABI = require('./abi/UNISWAP_V2_ERC20_ABI'); var _UNISWAP_V2_ERC20_ABI2 = _interopRequireDefault(_UNISWAP_V2_ERC20_ABI);

/**
 * Get the token contract addresses from the wallet's EdgeMetaTokens
 */
const getMetaTokenAddress = (
  metaTokens,
  tokenCurrencyCode
) => {
  const metaToken = metaTokens.find(mt => mt.currencyCode === tokenCurrencyCode)

  if (metaToken == null || _optionalChain([metaToken, 'optionalAccess', _ => _.contractAddress]) === undefined)
    throw new Error('Could not find contract address for ' + tokenCurrencyCode)

  return _nullishCoalesce(metaToken.contractAddress, () => ( ''))
}











/**
 * Determine if the tokens are wrapped and return the appropriate wrapped
 * contract addresses, if different.
 */
 const getInOutTokenAddresses = (
  currencyInfo,
  fromCurrencyCode,
  toCurrencyCode
) => {
  const { currencyCode: nativeCurrencyCode, metaTokens } = currencyInfo
  const wrappedCurrencyCode = `W${nativeCurrencyCode}`
  const isFromNativeCurrency = fromCurrencyCode === nativeCurrencyCode
  const isToNativeCurrency = toCurrencyCode === nativeCurrencyCode
  const isFromWrappedCurrency = fromCurrencyCode === wrappedCurrencyCode
  const isToWrappedCurrency = toCurrencyCode === wrappedCurrencyCode
  const isWrappingSwap =
    (isFromNativeCurrency && isToWrappedCurrency) ||
    (isFromWrappedCurrency && isToNativeCurrency)

  const fromTokenAddress = getMetaTokenAddress(
    metaTokens,
    isFromNativeCurrency ? wrappedCurrencyCode : fromCurrencyCode
  )
  const toTokenAddress = getMetaTokenAddress(
    metaTokens,
    isToNativeCurrency ? wrappedCurrencyCode : toCurrencyCode
  )

  return {
    fromTokenAddress,
    toTokenAddress,
    isWrappingSwap,
    isFromNativeCurrency,
    isToNativeCurrency,
    isFromWrappedCurrency,
    isToWrappedCurrency
  }
}; exports.getInOutTokenAddresses = getInOutTokenAddresses

const getEvmCheckSumAddress = (assetAddress) => {
  // if (assetAddress === ETHAddress) return ETHAddress
  return _ethers.ethers.utils.getAddress(assetAddress.toLowerCase())
}

 const getEvmApprovalData = async (params



) => {
  const { contractAddress, assetAddress, nativeAmount } = params
  const contract = new _ethers.ethers.Contract(
    assetAddress,
    _UNISWAP_V2_ERC20_ABI2.default,
    _ethers.ethers.providers.getDefaultProvider()
  )

  const bnNativeAmount = _ethers.ethers.BigNumber.from(nativeAmount)
  const approveTx = await contract.populateTransaction.approve(
    contractAddress,
    bnNativeAmount,
    {
      gasLimit: '500000',
      gasPrice: '20'
    }
  )
  return approveTx.data
}; exports.getEvmApprovalData = getEvmApprovalData

 const getEvmTokenData = async (params






) => {
  // const isETH = assetAddress === ETHAddress
  const {
    // usersSendingAddress,
    assetAddress,
    contractAddress,
    memo,
    vaultAddress,
    amountToSwapWei
  } = params

  // initialize contract
  const contract = new _ethers.ethers.Contract(
    contractAddress,
    _THORCHAIN_SWAP_ABI2.default,
    _ethers.ethers.providers.getDefaultProvider()
  )

  // Dummy gasPrice that we won't actually use
  const gasPrice = _ethers.ethers.BigNumber.from('50')

  // setup contract params
  const contractParams = [
    vaultAddress,
    getEvmCheckSumAddress(assetAddress),
    amountToSwapWei.toFixed(),
    memo,
    { gasPrice }
  ]

  // call the deposit method on the thorchain router.
  const tx = await contract.populateTransaction.deposit(...contractParams)
  if (tx.data == null) throw new Error('No data in tx object')
  return tx.data
}; exports.getEvmTokenData = getEvmTokenData
